@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -48,7 +48,7 @@ __all__ = ("CodeStarNotificationsClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -67,7 +67,7 @@ class Exceptions:
 
 class CodeStarNotificationsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html)
     """
 
@@ -83,7 +83,7 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#can_paginate)
         """
 
@@ -91,18 +91,18 @@ class CodeStarNotificationsClient(BaseClient):
         self,
         *,
         Name: str,
-        EventTypeIds: List[str],
+        EventTypeIds: Sequence[str],
         Resource: str,
-        Targets: List["TargetTypeDef"],
+        Targets: Sequence["TargetTypeDef"],
         DetailType: DetailTypeType,
         ClientRequestToken: str = None,
-        Tags: Dict[str, str] = None,
+        Tags: Mapping[str, str] = None,
         Status: NotificationRuleStatusType = None
     ) -> CreateNotificationRuleResultTypeDef:
         """
         Creates a notification rule for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#create_notification_rule)
         """
 
@@ -110,7 +110,7 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Deletes a notification rule for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#delete_notification_rule)
         """
 
@@ -120,7 +120,7 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Deletes a specified target for notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#delete_target)
         """
 
@@ -128,28 +128,28 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Returns information about a specified notification rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#describe_notification_rule)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#generate_presigned_url)
         """
 
     def list_event_types(
         self,
         *,
-        Filters: List["ListEventTypesFilterTypeDef"] = None,
+        Filters: Sequence["ListEventTypesFilterTypeDef"] = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListEventTypesResultTypeDef:
@@ -157,21 +157,21 @@ class CodeStarNotificationsClient(BaseClient):
         Returns information about the event types available for configuring
         notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_event_types)
         """
 
     def list_notification_rules(
         self,
         *,
-        Filters: List["ListNotificationRulesFilterTypeDef"] = None,
+        Filters: Sequence["ListNotificationRulesFilterTypeDef"] = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListNotificationRulesResultTypeDef:
         """
         Returns a list of the notification rules for an AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_notification_rules)
         """
 
@@ -179,21 +179,21 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Returns a list of the tags associated with a notification rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_tags_for_resource)
         """
 
     def list_targets(
         self,
         *,
-        Filters: List["ListTargetsFilterTypeDef"] = None,
+        Filters: Sequence["ListTargetsFilterTypeDef"] = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListTargetsResultTypeDef:
         """
         Returns a list of the notification rule targets for an AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_targets)
         """
 
@@ -205,15 +205,15 @@ class CodeStarNotificationsClient(BaseClient):
         associated target can receive notifications when the events described in the
         rule are triggered.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#subscribe)
         """
 
-    def tag_resource(self, *, Arn: str, Tags: Dict[str, str]) -> TagResourceResultTypeDef:
+    def tag_resource(self, *, Arn: str, Tags: Mapping[str, str]) -> TagResourceResultTypeDef:
         """
         Associates a set of provided tags with a notification rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#tag_resource)
         """
 
@@ -223,16 +223,16 @@ class CodeStarNotificationsClient(BaseClient):
         that subscribers to that topic stop receiving notifications when the events
         described in the rule are triggered.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#unsubscribe)
         """
 
-    def untag_resource(self, *, Arn: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, Arn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes the association between one or more provided tags and a notification
         rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#untag_resource)
         """
 
@@ -242,21 +242,21 @@ class CodeStarNotificationsClient(BaseClient):
         Arn: str,
         Name: str = None,
         Status: NotificationRuleStatusType = None,
-        EventTypeIds: List[str] = None,
-        Targets: List["TargetTypeDef"] = None,
+        EventTypeIds: Sequence[str] = None,
+        Targets: Sequence["TargetTypeDef"] = None,
         DetailType: DetailTypeType = None
     ) -> Dict[str, Any]:
         """
         Updates a notification rule for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#update_notification_rule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_event_types"]) -> ListEventTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listeventtypespaginator)
         """
 
@@ -265,13 +265,13 @@ class CodeStarNotificationsClient(BaseClient):
         self, operation_name: Literal["list_notification_rules"]
     ) -> ListNotificationRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listnotificationrulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_targets"]) -> ListTargetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listtargetspaginator)
         """
