@@ -22,7 +22,7 @@ Usage::
     list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -52,53 +52,53 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListEventTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listeventtypespaginator)
     """
 
     def paginate(
         self,
         *,
-        Filters: List["ListEventTypesFilterTypeDef"] = None,
+        Filters: Sequence["ListEventTypesFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListEventTypesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listeventtypespaginator)
         """
 
 
 class ListNotificationRulesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listnotificationrulespaginator)
     """
 
     def paginate(
         self,
         *,
-        Filters: List["ListNotificationRulesFilterTypeDef"] = None,
+        Filters: Sequence["ListNotificationRulesFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListNotificationRulesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listnotificationrulespaginator)
         """
 
 
 class ListTargetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listtargetspaginator)
     """
 
     def paginate(
         self,
         *,
-        Filters: List["ListTargetsFilterTypeDef"] = None,
+        Filters: Sequence["ListTargetsFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListTargetsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listtargetspaginator)
         """
